@@ -1,5 +1,5 @@
 from .correlations import (n2_correction, co2_correction, h2s_correction, pb, rs,
     bo, rho_oil, co, muod, muo,rsw, bw, cw, muw, rhow, rhog, z_factor, bg, eg, 
     critical_properties,critical_properties_correction, cg,mug, SetOilCorrelations, 
-    SetGasCorrelations, SetWaterCorrelations
+    SetGasCorrelations, SetWaterCorrelations,sg_to_api,api_to_sg
 )
\ No newline at end of file
